@@ -60,8 +60,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-flto -fuse-linker-plugin -ffat-lto-objects '
                              '-flto-partition=none -g',
  'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
-                "'--with-lto' '--enable-ipv6' '--with-system-expat' "
+ 'CONFIG_ARGS': "'ax_cv_c_float_words_bigendian=no' '--prefix=/usr' "
+                "'--enable-shared' '--with-computed-gotos' '--with-lto' "
+                "'--enable-ipv6' '--with-system-expat' "
                 "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
                 "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
@@ -76,9 +77,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python311/src/Python-3.11.2/coverage.info',
+ 'COVERAGE_INFO': '/build/python311/src/Python-3.11.9/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python311/src/Python-3.11.2/lcov-report',
+ 'COVERAGE_REPORT': '/build/python311/src/Python-3.11.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -86,6 +87,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CXX': 'g++',
  'DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
  'DECIMAL_LDFLAGS': '-lmpdec',
+ 'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
  'DEEPFREEZE_DEPS': './Tools/scripts/deepfreeze.py _bootstrap_python '
                     './Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
@@ -351,6 +353,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 1,
  'HAVE_LINUX_CAN_RAW_H': 1,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 1,
+ 'HAVE_LINUX_LIMITS_H': 1,
  'HAVE_LINUX_MEMFD_H': 1,
  'HAVE_LINUX_NETLINK_H': 1,
  'HAVE_LINUX_QRTR_H': 1,
@@ -433,6 +436,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
@@ -507,7 +511,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STRLCPY': 0,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
@@ -1087,12 +1091,13 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'Py_STATS': 0,
+ 'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1136,9 +1141,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.2 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.2 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python311/src/Python-3.11.9 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1169,8 +1174,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python311/src/Python-3.11.2',
- 'abs_srcdir': '/build/python311/src/Python-3.11.2',
+ 'abs_builddir': '/build/python311/src/Python-3.11.9',
+ 'abs_srcdir': '/build/python311/src/Python-3.11.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
